/*
 * $Source: /usr/cvsroot/melati/melati/src/main/java/org/melati/template/webmacro/WebmacroMelatiServlet.java,v $
 * $Revision: 1.18 $
 *
 * Copyright (C) 2000 Tim Joyce
 *
 * Part of Melati (http://melati.org), a framework for the rapid
 * development of clean, maintainable web applications.
 *
 * Melati is free software; Permission is granted to copy, distribute
 * and/or modify this software under the terms either:
 *
 * a) the GNU General Public License as published by the Free Software
 *    Foundation; either version 2 of the License, or (at your option)
 *    any later version,
 *
 *    or
 *
 * b) any version of the Melati Software License, as published
 *    at http://melati.org
 *
 * You should have received a copy of the GNU General Public License and
 * the Melati Software License along with this program;
 * if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA to obtain the
 * GNU General Public License and visit http://melati.org to obtain the
 * Melati Software License.
 *
 * Feel free to contact the Developers of Melati (http://melati.org),
 * if you would like to work out a different arrangement than the options
 * outlined here.  It is our intention to allow Melati to be used by as
 * wide an audience as possible.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * Contact details for copyright holder:
 *
 *     Tim Joyce <timj At paneris.org>
 */

package org.melati.template.webmacro;

import org.melati.Melati;
import org.melati.servlet.TemplateServlet;
import org.melati.template.ServletTemplateContext;
import org.melati.util.MelatiConfigurationException;

import org.webmacro.servlet.WebContext;

/**
 * Base class to use WebMacro (specifically) with Melati. 
 * 
 * Extend this class, overriding the {@link #handle(Melati, WebContext)} method.
 * 
 * If you are agnostic as to what TemplateEngine to use then extend {@link TemplateServlet} directly.
 *  
 * @author Tim Joyce
 * $Revision: 1.18 $
 */
public abstract class WebmacroMelatiServlet extends TemplateServlet {

  /**
   * Eclipse generated.
   */
  private static final long serialVersionUID = -7514187750618897237L;

  protected String doTemplateRequest(Melati m, ServletTemplateContext c) 
   throws Exception {
    if (!m.getTemplateEngine().getName().equals(WebmacroTemplateEngine.NAME)) 
      throw new MelatiConfigurationException("Configured TemplateEngine ("+ 
                    m.getTemplateEngine().getName() + ") " + 
                    "is not the required one (" + WebmacroTemplateEngine.NAME + ").");
    return handle(m, (WebContext)c.getContext());
  }
  
  protected abstract String handle(Melati m, WebContext c) 
   throws Exception;
  
}








